@@ -1,3 +1,25 @@
+con_pl_ll = function(x, pars, xmin) {
+  n = length(x)
+  joint_prob = colSums(sapply(pars, 
+                              function(i) dplcon(x, xmin, i, log=TRUE)))
+  #   ##Normalise due to xmax
+  prob_over = 0
+  #   if(!is.null(xmax))
+  #       prob_over = sapply(pars, function(i) 
+  #         log(ppldis(xmax, i, lower.tail=TRUE)))
+  #   
+  
+  return(joint_prob - n*prob_over)
+}
+
+
+
+
+
+
+
+
+
 conlnorm_tail_ll = function(x, pars, xmin) {
   if(is.vector(pars)) pars = t(as.matrix(pars))
   n = length(x)
@@ -22,6 +44,11 @@ conexp_tail_ll = function(x, rate, xmin) {
 
 
 
+
+
+
+
+
 # conlnorm_tail_ll(x, c(1,1), 1)
 # conexp_tail_ll(x, 1, 1)
 # 
