@@ -38,11 +38,11 @@ NULL
     
    
 
-#' @name NativeAmerican           
-#' @aliases NativeAmerican USAmerican
+#' @name native_american           
+#' @aliases NativeAmerican USAmerican us_american
 #' @title Casualities in the American Indian Wars (1776 and 1890)
 #' @description These data files contain the observed casualties in the American Indian Wars. The data sets 
-#' \code{NativeAmerican} and \code{USAmerican} contain the casualties on the Native American and US American 
+#' \code{native_american} and \code{us_american} contain the casualties on the Native American and US American 
 #' sides respectively. Each data set is a data frame, with two columns: the number of casualities and the
 #' conflict date.
 #' 
@@ -65,7 +65,22 @@ NULL
 #' arXiv preprint arXiv:1301.1674 (2013).
 NULL
 
-
+#' @name swiss_prot
+#' @aliases Swiss_prot
+#' @title Word frequency in the Swiss-Prot data base
+#' @description This dataset contains all the words extracted from the 
+#' Swiss-Prot version 9 data (with the resulting frequency for each word).
+#' Other datasets for other database versions can be obtained by contacting 
+#' Michael Bell 
+#' (http://homepages.cs.ncl.ac.uk/m.j.bell1/annotationQualityPaper.php) 
+#' 
+#' @docType data
+#' @format data frame
+#' @source Bell, MJ, Gillespie, CS, Swan, D, Lord, P. 
+#' An approach to describing and analysing bulk biological annotation 
+#' quality: A case study using UniProtKB. 
+#' Bioinformatics 2012, 28, i562-i568.
+NULL
 
 
 
